KLWFMult: Cocktail Algorithm for KL-Optimality

View source: R/kl_optim.R

KLWFMultR Documentation

Cocktail Algorithm for KL-Optimality

Description

Cocktail Algorithm for KL-Optimality

Usage

KLWFMult(
  init_design,
  kl_fun,
  beta2_init,
  lower,
  upper,
  design_space,
  grid.length,
  join_thresh,
  delete_thresh,
  delta_weights,
  tol,
  tol2,
  max_iter,
  kl_meta = list(type = "kl_fun")
)

Arguments

init_design

optional dataframe with the initial design for the algorithm.

kl_fun

function(x, beta2); returns the KL divergence at design point x given rival parameters beta2.

beta2_init

numeric vector of initial rival parameter values.

lower

lower bounds for rival parameters in the inner optimisation.

upper

upper bounds for rival parameters in the inner optimisation.

design_space

named list with bounds for each design variable.

grid.length

numeric value for the sensitivity search grid / LHS size.

join_thresh

numeric value for the merge heuristic.

delete_thresh

numeric value for the weight deletion threshold.

delta_weights

numeric value in (0, 1), parameter of the algorithm.

tol

numeric value for convergence of the weight loop.

tol2

numeric value for the outer stop condition.

max_iter

maximum number of outer iterations.

kl_meta

list with summary metadata (type, and optionally family and phi for the standard path).

Value

An object of class optdes.

See Also

Other cocktail algorithms: CWFMult(), DWFMult(), DsWFMult(), IWFMult(), WFMult()


optedr documentation built on June 23, 2026, 5:07 p.m.