WFMult: Master function for the cocktail algorithm, that calls the...

View source: R/wf_mult.R

WFMultR Documentation

Master function for the cocktail algorithm, that calls the appropriate one given the criterion.

Description

Depending on the criterion the cocktail algorithm for the chosen criterion is called, and the necessary parameters for the functions are given from the user input.

Usage

WFMult(
  init_design,
  grad,
  criterion,
  par_int = NA,
  matB = NA,
  design_space,
  grid.length,
  join_thresh,
  delete_thresh,
  k,
  delta_weights,
  tol,
  tol2,
  max_iter,
  compound = NULL,
  kl_spec = NULL
)

Arguments

init_design

optional dataframe with the initial design for the algorithm.

grad

function of partial derivatives of the model.

criterion

character variable with the chosen optimality criterion.

par_int

numeric vector with the index of the parameters of interest (Ds-Optimality).

matB

optional matrix for L-optimality.

design_space

named list with bounds for each design variable.

grid.length

numeric value for the sensitivity search grid / LHS size.

join_thresh

numeric value for the merge heuristic.

delete_thresh

numeric value for the weight deletion threshold.

k

number of unknown parameters of the model.

delta_weights

numeric value in (0, 1), parameter of the algorithm.

tol

numeric value for convergence of the weight loop.

tol2

numeric value for the outer stop condition.

max_iter

maximum number of outer iterations.

compound

preprocessed list of compound criterion specifications (internal use).

kl_spec

preprocessed list of KL-Optimality specifications (internal use).

Value

An object of class optdes.

See Also

Other cocktail algorithms: CWFMult(), DWFMult(), DsWFMult(), IWFMult(), KLWFMult()


optedr documentation built on June 23, 2026, 5:07 p.m.