detect_design_vars: Detect design variables from a model formula

View source: R/detect_design.R

detect_design_varsR Documentation

Detect design variables from a model formula

Description

Inspects the formula to identify which symbols are design variables (as opposed to parameters or the response). Enforces the naming convention: "x" for single-factor models and "x1", "x2", ... for multi-factor models.

Usage

detect_design_vars(model, parameters)

Arguments

model

A formula describing the model.

parameters

Character vector of parameter names (excluded from design variables).

Value

Character vector of design variable names, sorted in numerical order for multi-factor models (e.g. c("x1", "x2", "x10")).


optedr documentation built on June 23, 2026, 5:07 p.m.