dsens: Sensitivity function for D-Optimality

View source: R/inf_mat_sens.R

dsensR Documentation

Sensitivity function for D-Optimality

Description

Calculates the sensitivity function from the gradient vector and the Identity Matrix.

Usage

dsens(grad, M)

Arguments

grad

A function in a single variable that returns the partial derivatives vector of the model.

M

Information Matrix for the sensitivity function.

Value

The sensitivity function as a matrix of single variable.


optedr documentation built on June 23, 2026, 5:07 p.m.