get_laugment_region: Get L-augment region

View source: R/augment.R

get_laugment_regionR Documentation

Get L-augment region

Description

Given a model, calculates the candidate points region for L-Optimality. The user gives an initial design for which he would like to add points and specifies the weight of the new points. Then he is prompted to choose a minimum efficiency. After that, the candidate points region is calculated.

Usage

get_laugment_region(
  init_design,
  alpha,
  model,
  parameters,
  par_values,
  design_space,
  calc_optimal_design,
  matB,
  weight_fun = function(x) 1,
  delta_val = NULL
)

Arguments

init_design

dataframe with "Point" and "Weight" columns that represents the initial design to augment

alpha

combined weight of the new points

model

formula that represent the model with x as the independent variable

parameters

character vector with the unknown parameters of the model to estimate

par_values

numeric vector with the initial values of the unknown parameters

design_space

numeric vector with the limits of the space of the design

calc_optimal_design

boolean parameter, if TRUE, the optimal design is calculated and efficiencies of the initial and augmented design are given

matB

optional matrix of dimensions k x k, for L-optimality.

weight_fun

optional one variable function that represents the square of the structure of variance, in case of heteroscedastic variance of the response

delta_val

optional numeric value for the minimum relative efficiency. If NULL (default), the user is prompted interactively. Providing this value enables non-interactive use.

Value

A vector of the points limiting the candidate points region

See Also

Other augment region: get_dsaugment_region()

Examples


init_des <- data.frame("Point" = c(30, 60, 90), "Weight" = c(1/3, 1/3, 1/3))
get_augment_region("D-Optimality", init_des, 0.25, y ~ 10^(a - b/(c + x)),
  c("a", "b", "c"), c(8.07131, 1730.63, 233.426), c(1, 100), FALSE,
  delta_val = 0.85)


optedr documentation built on June 23, 2026, 5:07 p.m.