| plot.optdes | R Documentation |
For single-factor models, overlays the support points on the sensitivity function curve. For two-factor models, shows a heatmap of the sensitivity function with the support points overlaid and the Equivalence Theorem contour highlighted. For models with more than two factors, shows a pairwise scatter matrix with one panel per pair of design variables and point size proportional to weight.
## S3 method for class 'optdes'
plot(x, ...)
x |
An object of class |
... |
Possible extra arguments (currently unused). |
rri <- opt_des(criterion = "I-Optimality", model = y ~ a * exp(-b / x),
parameters = c("a", "b"), par_values = c(1, 1500), design_space = c(212, 422),
reg_int = c(380, 422))
plot(rri)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.