| check_inputs | R Documentation |
Function to check that the inputs given to the function opt_des are correct. If not, throws the
correspondent error message.
check_inputs(
criterion,
model,
parameters,
par_values,
design_space,
init_design,
join_thresh,
delete_thresh,
delta,
tol,
tol2,
par_int,
matB,
reg_int,
weight_fun
)
criterion |
character variable with the chosen optimality criterion. |
model |
formula describing the model. For single-factor models use |
parameters |
character vector with the parameter names. |
par_values |
numeric vector with the nominal parameter values. |
design_space |
For single-factor models: numeric vector |
init_design |
optional dataframe with the initial design. For single-factor models
use columns |
join_thresh |
optional numeric threshold for merging nearby design points. |
delete_thresh |
optional numeric minimum weight to keep a support point. |
delta |
optional numeric in (0, 1), damping parameter of the algorithm. |
tol |
optional numeric for convergence of the weight loop. |
tol2 |
optional numeric for the outer stop condition. |
par_int |
optional numeric vector of parameter indices for Ds-optimality. |
matB |
optional k x k matrix for L-optimality. |
reg_int |
optional bounds for the I-optimality integration region.
Single-factor: |
weight_fun |
optional variance-structure weight function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.