View source: R/detect_design.R
| detect_design_vars | R Documentation |
Inspects the formula to identify which symbols are design variables (as opposed to
parameters or the response). Enforces the naming convention: "x" for
single-factor models and "x1", "x2", ... for multi-factor models.
detect_design_vars(model, parameters)
model |
A formula describing the model. |
parameters |
Character vector of parameter names (excluded from design variables). |
Character vector of design variable names, sorted in numerical order for
multi-factor models (e.g. c("x1", "x2", "x10")).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.